@@ -41,7 +41,7 @@ AESCrypt::AESCrypt()
 {
 }
     
-AESCrypt::AESCrypt(const Chain& keyString, int keyLen)
+AESCrypt::AESCrypt(const Chain& keyString, unsigned keyLen)
 {
     // The number of rounds in AES Cipher. It is simply initiated to zero. The actual value is recieved in the program.
     _Nr=0;
@@ -54,7 +54,7 @@ AESCrypt::AESCrypt(const Chain& keyString, int keyLen)
     _Nk = _Nr / 32;
     _Nr = _Nk + 6;
 
-    if ( (int)keyString.length() < _Nk*4 )	
+    if ( (unsigned)keyString.length() < _Nk*4 )	
 	throw Exception(EXLOC, "Key string too short");
 
     // keyLen must be either 128,192 or 256    
@@ -62,7 +62,7 @@ AESCrypt::AESCrypt(const Chain& keyString, int keyLen)
 	throw Exception(EXLOC, "Invalid keylen ( 128,192 or 256 are valid )");
 
     // Copy the Key and PlainText
-    for(int i=0; i<_Nk*4; i++)
+    for(unsigned i=0; i<_Nk*4; i++)
     {
         _Key[i]=keyString[i];
         // _in[i]=temp2[i];
@@ -77,7 +77,7 @@ AESCrypt::~AESCrypt()
 {
 }
  
-unsigned char AESCrypt::getSBoxValue(int num)
+unsigned char AESCrypt::getSBoxValue(unsigned num)
 {
     unsigned char sbox[256] =   {
 	//0     1    2      3     4    5     6     7      8    9     A      B    C     D     E     F
@@ -103,7 +103,7 @@ unsigned char AESCrypt::getSBoxValue(int num)
 // The round constant word array, Rcon[i], contains the values given by 
 // x to th e power (i-1) being powers of x (x is denoted as {02}) in the field GF(28)
 // Note that i starts at 1, not 0).
-unsigned char AESCrypt::getRconValue(int num)
+unsigned char AESCrypt::getRconValue(unsigned num)
 {
     unsigned char rcon[255] = {
 
@@ -129,7 +129,7 @@ unsigned char AESCrypt::getRconValue(int num)
 // This function produces Nb(Nr+1) round keys. The round keys are used in each round to encrypt the states. 
 void AESCrypt::KeyExpansion()
 {
-    int i,j;
+    unsigned i,j;
     unsigned char temp[4],k;
     
     // The first round key is the key itself.
@@ -195,9 +195,9 @@ void AESCrypt::KeyExpansion()
  
 // This function adds the round key to state.
 // The round key is added to the state by an XOR function.
-void AESCrypt::AddRoundKey(int round) 
+void AESCrypt::AddRoundKey(unsigned round) 
 {
-    int i,j;
+    unsigned i,j;
     for(i=0;i<4;i++)
     {
         for(j=0;j<4;j++)
@@ -211,7 +211,7 @@ void AESCrypt::AddRoundKey(int round)
 // state matrix with values in an S-box.
 void AESCrypt::SubBytes()
 {
-    int i,j;
+    unsigned i,j;
     for(i=0;i<4;i++)
     {
         for(j=0;j<4;j++)
@@ -257,7 +257,7 @@ void AESCrypt::ShiftRows()
 // Refer the documents specified above.
 void AESCrypt::MixColumns()
 {
-    int i;
+    unsigned i;
     unsigned char Tmp,Tm,t;
     for(i=0;i<4;i++)
     {    
@@ -279,7 +279,7 @@ unsigned char AESCrypt::xtime(unsigned char x)
 // Cipher is the main function that encrypts the PlainText.
 void AESCrypt::Cipher()
 {
-    int i,j,round=0;
+    unsigned i,j,round=0;
  
     //Copy the input PlainText to state array.
     for(i=0;i<4;i++)
@@ -340,18 +340,18 @@ Chain AESCrypt::encrypt(const Chain& val)
 
     char outBuf[MAXOUTBUF];
 
-    int i;
-    int offset=0;
+    unsigned i;
+    unsigned offset=0;
 
-    for ( i=0; i<(int)val.length(); i+=16 )
+    for ( i=0; i<(unsigned)val.length(); i+=16 )
     {
     
-	int j;
+	unsigned j;
 
 	// Copy the Key and PlainText
 	for(j=0; j<16; j++)
 	{
-	    if ( i+j < (int)val.length() )
+	    if ( i+j < (unsigned)val.length() )
 		_in[j]=val[i + j];
 	    else
 		_in[j]=0;
