@@ -86,7 +86,7 @@ BigDecimal::BigDecimal(const Chain& val)
     // cout << "Val=" << _val << endl;
 }
 
-BigDecimal::BigDecimal(const Chain& val, int scale)
+BigDecimal::BigDecimal(const Chain& val, unsigned scale)
 {
 
     /* this is a private constructor, so no need for any format validation */
@@ -109,11 +109,11 @@ BigDecimal::BigDecimal(const Chain& val, int scale)
     
     _scale = scale;
     
-    if ( (int)_val.length() - 1  <= _scale )
+    if ( (unsigned)_val.length() - 1  <= _scale )
     {
-	int j = (int)_val.length() - 1;
+	unsigned j = (unsigned)_val.length() - 1;
 		
-	for ( int i = j; i <= _scale ; i++)
+	for ( unsigned i = j; i <= _scale ; i++)
 	{
 	    _val = "0" + _val;
 	}
@@ -144,7 +144,7 @@ BigDecimal BigDecimal::add(const BigDecimal& d) const
 {
     Chain v1 = _val;
     Chain v2 = d._val;
-    int maxScale;
+    unsigned maxScale;
 
     if ( _scale > d._scale )
     {
@@ -181,7 +181,7 @@ BigDecimal BigDecimal::sub(const BigDecimal& d) const
 
     Chain v1 = _val;
     Chain v2 = d._val;
-    int maxScale;
+    unsigned maxScale;
 
     if ( _scale > d._scale )
     {
@@ -234,20 +234,20 @@ BigDecimal BigDecimal::div(const BigDecimal& d) const
     Chain v1 = _val;
     Chain v2 = d._val;
 
-    int i=0;
-    while ( i < (int)v1.length() )
+    unsigned i=0;
+    while ( i < (unsigned)v1.length() )
     {
         if ( v1[i] != '0' )
            break;
         i++;
     }
 
-    if ( i == (int)v1.length() - 1 )
+    if ( i == (unsigned)v1.length() - 1 )
     {
         return BigDecimal();
     }	 
-    int maxScale;
-    int corScale;
+    unsigned maxScale;
+    unsigned corScale;
     
     if ( d._scale > _scale )
     {	
@@ -289,9 +289,9 @@ BigDecimal BigDecimal::div(const BigDecimal& d) const
 	i3.negate();
     
     Chain v = i3.toChain();
-    if ( (int)(i3.toChain().length())-1 < maxScale )
+    if ( (unsigned)(i3.toChain().length())-1 < maxScale )
     {
-	int c = 1 + maxScale - ( (int)(i3.toChain().length()) -1 );
+	unsigned c = 1 + maxScale - ( (unsigned)(i3.toChain().length()) -1 );
 	while ( c )
 	{
 	    v = Chain("0") + v;
@@ -304,7 +304,7 @@ BigDecimal BigDecimal::div(const BigDecimal& d) const
     return BigDecimal(v, maxScale); 
 }
 
-BigDecimal BigDecimal::scaleTo(int scale, RoundMode mode) const
+BigDecimal BigDecimal::scaleTo(unsigned scale, RoundMode mode) const
 {
 
     // cout << "Scale=" << _scale << endl;
@@ -321,7 +321,7 @@ BigDecimal BigDecimal::scaleTo(int scale, RoundMode mode) const
     else if ( scale > _scale )
     {
 	Chain val = _val;
-	int c = scale - _scale;
+        unsigned c = scale - _scale;
 	while ( c )
 	{
 	    val = val + Chain("0");
@@ -331,7 +331,7 @@ BigDecimal BigDecimal::scaleTo(int scale, RoundMode mode) const
     }
     else
     {
-	int deltaScale = _scale - scale;
+	unsigned deltaScale = _scale - scale;
 	
 	Chain roundVal = _val.subChain(1, _val.length() - deltaScale -1);	
 	Chain roundCheck =  _val.subChain(_val.length() - deltaScale , _val.length() - deltaScale);
@@ -349,7 +349,7 @@ BigDecimal BigDecimal::scaleTo(int scale, RoundMode mode) const
 	if ( roundUp ) // roundCheck.asInteger() >= 5 )
 	{
 	    Chain delta = Chain("0");
-	    for ( int i=0; i<scale-1; i++ )
+	    for ( unsigned i=0; i<scale-1; i++ )
 		delta += Chain("0");
 	    delta += Chain("1");	    
 	    scaleTarget = BigDecimal(roundVal, scale) + BigDecimal(delta, scale);
@@ -366,12 +366,12 @@ BigDecimal BigDecimal::scaleTo(int scale, RoundMode mode) const
     return scaleTarget;
 }
 
-int BigDecimal::getScale() const
+unsigned BigDecimal::getScale() const
 {
     return _scale;
 }
 
-int BigDecimal::length() const
+unsigned long long BigDecimal::length() const
 {
     return _val.length();
 }
@@ -502,7 +502,7 @@ ostream& operator << (ostream& s, const  BigDecimal& d)
     return s;
 }
 
-Chain BigDecimal::mulDec(const Chain& val, int dim) const
+Chain BigDecimal::mulDec(const Chain& val, unsigned dim) const
 {
     Chain res = val;
     while ( dim > 0 )
@@ -524,7 +524,7 @@ int BigDecimal::compAbs(const BigDecimal& d) const
         if ( _scale < d._scale )
         {
 	    Chain dval = _val;
-	    int i=0;
+	    unsigned i=0;
 	    while ( i < d._scale - _scale )
 	    {
 		dval+="0";
@@ -541,7 +541,7 @@ int BigDecimal::compAbs(const BigDecimal& d) const
         else
         {
 	    Chain dval = d._val;
-	    int i=0;
+	    unsigned i=0;
 	    while ( i < _scale - d._scale )
 	    {
 		dval+="0";
