@@ -42,10 +42,10 @@ public:
     BigDecimal sub(const BigDecimal& d) const;
     BigDecimal mul(const BigDecimal& d) const;
     BigDecimal div(const BigDecimal& d) const;
-    BigDecimal scaleTo(int scale, RoundMode mode = DOWN ) const;
+    BigDecimal scaleTo(unsigned scale, RoundMode mode = DOWN ) const;
 
-    int getScale() const;
-    int length() const;
+    unsigned getScale() const;
+    unsigned long long length() const;
     
     Chain toChain() const;
     
@@ -67,14 +67,14 @@ public:
     
 private:
 
-    BigDecimal(const Chain& val, int scale);
+    BigDecimal(const Chain& val, unsigned scale);
     
-    Chain mulDec(const Chain& val, int dim) const;
+    Chain mulDec(const Chain& val, unsigned dim) const;
     int compAbs(const BigDecimal& d) const;
     
     bool _isPositive;
     Chain _val;
-    int _scale;
+    unsigned _scale;
 };
 #endif
 
