@@ -85,15 +85,15 @@ BigInteger BigInteger::add(const BigInteger& d) const
     if ( ( isPositive() == true && d.isPositive() == true )
 	 || ( isPositive() == false  && d.isPositive() == false) )
     {
-	int l = length() < d.length() ? d.length() : length();
+	unsigned long long l = length() < d.length() ? d.length() : length();
 	
-	int carry = 0;
-	int rest = 0;
+	unsigned carry = 0;
+	unsigned rest = 0;
 	
 	Chain r;
-	for ( int i = 1 ; i <= l ; i++ )
+	for ( unsigned long long  i = 1 ; i <= l ; i++ )
 	{
-	    int j = getDigit(length() - i) + d.getDigit(d.length() - i) + carry;
+	    unsigned  j = getDigit(length() - i) + d.getDigit(d.length() - i) + carry;
 	    
 	    rest = j % 10;
 	    carry = j / 10;
@@ -124,16 +124,17 @@ BigInteger BigInteger::sub(const BigInteger& d) const
     {
 	if ( *this >= d )
 	{
-	    int l = length() < d.length() ? d.length() : length();
+	    unsigned long long l = length() < d.length() ? d.length() : length();
+
 	    
-	    int carry = 0;
-	    int rest = 0;
+	    unsigned carry = 0;
+	    unsigned rest = 0;
 	    
 	    Chain r;
-	    for ( int i = 1 ; i <= l ; i++ )
+	    for ( unsigned long long i = 1 ; i <= l ; i++ )
 	    {
 		
-		int j = getDigit(length() - i) - d.getDigit(d.length() - i) - carry;
+		int j = (int)getDigit(length() - i) - (int)d.getDigit(d.length() - i) - carry;
 		if ( j < 0 )
 		{
 		    rest = 10 + j;
@@ -182,7 +183,7 @@ BigInteger BigInteger::mul(const BigInteger& d) const
 {
  
     BigInteger res;
-    for ( int i = 1 ; i < d.length() ; i ++ )
+    for ( unsigned long long i = 1 ; i < d.length() ; i ++ )
     {
 	BigInteger s = mulDigit(d.getDigit(d.length() - i));
 	if ( i == 1 )
@@ -191,7 +192,7 @@ BigInteger BigInteger::mul(const BigInteger& d) const
 	}
 	else
 	{
-	    int j;
+	    unsigned long long j;
 	    Chain n = s.toChain();
 	    for ( j=1; j<i ; j++)
 		n = n + Chain(0);
@@ -206,14 +207,14 @@ BigInteger BigInteger::mul(const BigInteger& d) const
     return res;
 }
 
-BigInteger BigInteger::mulDigit(int f) const
+BigInteger BigInteger::mulDigit(unsigned f) const
 {     
     Chain d;
-    int carry = 0;
-    int rest = 0;
-    for ( int i=1 ; i <= length() ; i++ )
+    unsigned carry = 0;
+    unsigned rest = 0;
+    for ( unsigned long long i=1 ; i <= length() ; i++ )
     {
-	int m = getDigit(length() - i) * f + carry;
+	unsigned m = getDigit(length() - i) * f + carry;
 	rest = m % 10;
 	carry = m / 10;
 	d = Chain(rest) + d;
@@ -232,36 +233,39 @@ BigInteger BigInteger::div(const BigInteger& d) const
 	return BigInteger(0);
 
     BigInteger divPart;
-    int j = 1;
+    unsigned long long j = 1;
     Chain res;
-    while ( j < (int)_val.length() )
+    while ( j < _val.length() )
     {
 	
 	divPart = BigInteger( divPart.toChain() + _val.subChain(j,j) );
-	// cout << "DivPart=" << divPart << endl;
 
 	j++;
-	while ( divPart < d && j <= (int)_val.length() ) 
+	while ( divPart < d && j <= _val.length() ) 
 	{
-
 	    divPart = BigInteger( divPart.toChain() + _val.subChain(j,j) );
-	    // cout << "divPart ->" << divPart << endl;
 	    j++;
 	    res = res + Chain(0);
-	    // cout << "Res=" << res << endl;
 	}
 
-	if ( j <= (int)_val.length() )
+	if ( j <= _val.length() )
 	{
+	    
 	    BigInteger s;
 	    int mod=0;
 	    while ( s < divPart ) 
 	    {
 		mod++;
+		
 		s = s.add(d);
+		
 	    }
 	    if ( s > divPart )
 		mod--;
+
+
+	    // cout << "DivPart = " <<  divPart << endl;
+	    // cout << "d = " <<  d << endl;
 	    
 	    while ( divPart >= d )
 	    {
@@ -285,12 +289,12 @@ BigInteger BigInteger::div(const BigInteger& d) const
     return dres; 
 }
 
-int BigInteger::length() const
+unsigned long long BigInteger::length() const
 {
-    return (int)_val.length();
+    return _val.length();
 }
 
-int BigInteger::getDigit(int i) const
+unsigned BigInteger::getDigit(unsigned long long i) const
 {
     if ( i < length() && i > 0)
 	return _val.subChain(i, i).asInteger();
@@ -353,7 +357,7 @@ bool BigInteger::operator < ( const BigInteger& d) const
 	}
 	else
 	{
-	    for ( int i=1 ; i<length() ; i++ )
+	    for ( unsigned long long i=1 ; i<length() ; i++ )
 	    {
 		if ( getDigit(i) < d.getDigit(i) )
 		    return true;
@@ -388,7 +392,7 @@ bool BigInteger::operator > ( const BigInteger& d) const
 	}
 	else
 	{
-	    for ( int i=1 ; i<length() ; i++ )
+	    for ( unsigned long long i=1 ; i<length() ; i++ )
 	    {
 		if ( getDigit(i) > d.getDigit(i) )
 		    return true;
