@@ -68,7 +68,7 @@ Chain::Chain(const char *s)
      _len=sl;
 }
 
-Chain::Chain(const char *s, int len)
+Chain::Chain(const char *s, unsigned long len)
 {
      _buf = 0;
      _len = 0;
@@ -255,7 +255,7 @@ Chain::Chain(float f)
 {    
     char tmpBuf[TMPBUFSIZE];
 
-    int l = snprintf(tmpBuf, TMPBUFSIZE, "%f", f);
+    unsigned long l = snprintf(tmpBuf, TMPBUFSIZE, "%f", f);
     if ( l > TMPBUFSIZE )
     {
 	throw Exception(EXLOC, "Temp buf size exceeded"); 
@@ -282,7 +282,7 @@ Chain::Chain(double d, const char* format)
 {    
     char tmpBuf[TMPBUFSIZE];
     
-    int l = snprintf(tmpBuf, TMPBUFSIZE, format, d);
+    unsigned long l = snprintf(tmpBuf, TMPBUFSIZE, format, d);
     if ( l > TMPBUFSIZE )
     {
 	throw Exception(EXLOC, "Temp buf size exceeded"); 
@@ -344,7 +344,7 @@ unsigned long Chain::visibleLength() const
 Chain Chain::toUpper() const
 {
      Chain s = *this;
-
+     
      wchar_t wText[_len];
 
      if ( ::mbstowcs(wText, _buf, _len) == (size_t)-1 )
@@ -365,7 +365,7 @@ Chain Chain::toUpper() const
      {
 	 throw Exception(EXLOC, "Cannot convert to multi byte"); 
      }
-          
+
      return s;
 }
 
@@ -721,12 +721,12 @@ Chain Chain::truncRight(const Chain& str) const
     return *this;
 }
 
-bool Chain::posStr(const Chain& s1, int& result, int start, int occur) const
+bool Chain::posStr(const Chain& s1, unsigned long& result, long start, unsigned occur) const
 {
-    int ocount=1;
+    unsigned ocount=1;
     if ( start >=0 )
     {
-	for (int i=start; i<(int)_len; i++)
+	for (unsigned long i=(unsigned long)start; i<_len; i++)
 	{
 	    if ( matchAtPos(s1, i) )
 	    {
@@ -742,7 +742,7 @@ bool Chain::posStr(const Chain& s1, int& result, int start, int occur) const
     }
     else
     {
-	for (int i=_len-1; i>0; i--)
+	for (unsigned long i=_len-1; i>0; i--)
 	{
 	    if ( matchAtPos(s1, i) )
 	    {
@@ -759,13 +759,13 @@ bool Chain::posStr(const Chain& s1, int& result, int start, int occur) const
     return false;
 }
 
-bool Chain::matchAtPos(const Chain& s1, int pos) const
+bool Chain::matchAtPos(const Chain& s1, unsigned long pos) const
 {
     if ( _buf[pos] == s1[0] )
     {	    
-	int j=0;
+	unsigned long j=0;
 	bool match = true;
-	while (match && j < (int)s1.length()-1 && pos+j < (int)_len) 
+	while (match && j < s1.length()-1 && pos+j < _len) 
 	{
 	    if ( _buf[pos+j] != s1[j] )
 	    {
@@ -776,7 +776,7 @@ bool Chain::matchAtPos(const Chain& s1, int pos) const
 		j++;
 	    } 
 	}
-	if (match && j == (int)s1.length()-1)
+	if (match && j == s1.length()-1)
 	{  
 	    return true;		
 	}
@@ -787,13 +787,13 @@ bool Chain::matchAtPos(const Chain& s1, int pos) const
 
 bool Chain::replace(const Chain& s1, const Chain& s2, Chain& result) const
 {
-    for (int i=0; i<(int)_len; i++)
+    for (unsigned long i=0; i<_len; i++)
     {
 	if ( _buf[i] == s1[0] )
 	{	    
-	    int j=0;
+	    unsigned long j=0;
 	    bool match = true;
-	    while (match && j < (int)s1.length()-1 && i+j < (int)_len) 
+	    while (match && j < s1.length()-1 && i+j < _len) 
 	    {
 		if ( _buf[i+j] != s1[j] )
 		{
@@ -805,7 +805,7 @@ bool Chain::replace(const Chain& s1, const Chain& s2, Chain& result) const
 		    j++;
 		} 
 	    }
-	    if (match && j == (int)s1.length()-1)
+	    if (match && j == s1.length()-1)
 	    {
 				
 		Chain a, c;
@@ -813,7 +813,7 @@ bool Chain::replace(const Chain& s1, const Chain& s2, Chain& result) const
 		{
 		    a = subChain(1,i);
 		}
-		if (i+j < (int)_len)
+		if (i+j < _len)
 		{
 		    c = subChain(i+1+j, _len);
 		}
@@ -827,20 +827,20 @@ bool Chain::replace(const Chain& s1, const Chain& s2, Chain& result) const
     return false;
 }
 
-int Chain::replaceAll(const Chain& s1, const Chain& s2, Chain& result) const
+unsigned long Chain::replaceAll(const Chain& s1, const Chain& s2, Chain& result) const
 {
     Chain target; 
-    int count=0; 
-    int l=0; 
+    unsigned long count=0; 
+    unsigned long l=0; 
     Chain c; 
-    int i=0; 
-    while( i < (int)_len ) 
+    unsigned long i=0; 
+    while( i < _len ) 
     { 
         if ( _buf[i] == s1[0] ) 
         { 
-            int j=0; 
+            unsigned long j=0; 
             bool match = true; 
-            while (match && j < (int)s1.length()-1 && i+j < (int)_len) 
+            while (match && j < s1.length()-1 && i+j < _len) 
             { 
                 if ( _buf[i+j] != s1[j] ) 
                 { 
@@ -851,7 +851,7 @@ int Chain::replaceAll(const Chain& s1, const Chain& s2, Chain& result) const
                     j++; 
                 } 
             } 
-            if (match && j == (int)s1.length()-1) 
+            if (match && j == s1.length()-1) 
             { 
                 Chain a; 
                 if (i > l) 
@@ -886,24 +886,24 @@ int Chain::replaceAll(const Chain& s1, const Chain& s2, Chain& result) const
     return count; 
 }
 
-void Chain::setChar(int i, char c)
+void Chain::setChar(unsigned long i, char c)
 {
     _buf[i] = c;
 }
 
-int Chain::getHashPos(int hashSize) const
+unsigned long Chain::getHashPos(unsigned long hashSize) const
 {    
-    int val=0;
-    for ( int i=0; i<(int)_len; i++)
+    unsigned long val=0;
+    for ( unsigned long i=0; i<_len; i++)
     {
-	val += (int)_buf[i] ;
+	val += (unsigned long)_buf[i] ;
     }
     return ( val * ( hashSize / 100 + 1))  % hashSize;
 }
 
-Chain Chain::subChain(int l, int u) const
+Chain Chain::subChain(unsigned long l, unsigned long u) const
 {
-    if (l >= 0 && u <= (int)_len && l <= u)
+    if (l >= 0 && u <= _len && l <= u)
     {
 	char *tmpBuf = (char*)malloc(u-l+2);
 	
@@ -926,9 +926,9 @@ Chain Chain::subChain(int l, int u) const
     }
 }
 
-char Chain::operator [] (int i) const
+char Chain::operator [] (unsigned long i) const
 {
-    if (i < (int)_len)
+    if (i < _len)
     {
 	return _buf[i];
     }
