@@ -25,11 +25,6 @@
 
 #include <string.h>
 
-#ifdef HAVE_MINGW
-#include <winsock2.h>
-#include <windows.h>
-#define CLOSESOCKET ::closesocket
-#else
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -37,8 +32,6 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 #define TIMEVAL struct timeval
-#define CLOSESOCKET ::close
-#endif
 
 #include <errno.h>
 
@@ -46,28 +39,7 @@
 #include "Net.h"
 #include "NetHandler.h"
 
-// on FreeBSD based systems, a SENDLEN value of 1024 byte
-// lead to poor performance for large messages
-// So for modern network stacks a sendlen of 8192 might be useful
-
-// #define SENDLEN 8192
-
-/*
-NetHandler::NetHandler(int initMsgBufLen, int sizeInfoLen, int maxSendLen)
-{
-    _socket=0;
-    _msgSize=0;
-    _msgBufSize = initMsgBufLen;
-    _sizeInfoLen = sizeInfoLen;
-    _maxSendLen = maxSendLen;
-    
-    _concatPos = 0;
-
-    _msgBuf = new char[_msgBufSize + _sizeInfoLen];
-}
-*/
-
-NetHandler::NetHandler(int s, int initMsgBufLen, int sizeInfoLen, int maxSendLen)
+NetHandler::NetHandler(int s, unsigned initMsgBufLen, unsigned sizeInfoLen, unsigned maxSendLen)
 {
     _socket=s;
     _msgSize=0;
@@ -80,7 +52,7 @@ NetHandler::NetHandler(int s, int initMsgBufLen, int sizeInfoLen, int maxSendLen
 NetHandler::~NetHandler()
 {
     if ( _socket )
-	CLOSESOCKET(_socket);
+	::close(_socket);
     delete _msgBuf;
 }
 
@@ -99,7 +71,7 @@ const Chain& NetHandler::getSource() const
     return _source;
 }
 
-bool NetHandler::waitMsg(int ms)
+bool NetHandler::waitMsg(unsigned ms)
 {
     int result;
 
@@ -144,7 +116,7 @@ void NetHandler::readMsg()
 	throw Exception(EXLOC, msg);
     }
 
-    int i = 0;
+    unsigned i = 0;
     while ( _msgBuf[i] != '@' && i < _sizeInfoLen)
     {
 	i++;
@@ -188,7 +160,7 @@ void NetHandler::writeMsg()
 
     Chain sizeInfo(_msgSize);
    
-    if ( (int)sizeInfo.length() > _sizeInfoLen )
+    if ( (unsigned)sizeInfo.length() > _sizeInfoLen )
     {
 	Chain msg = Chain("Message too long : ") + sizeInfo;
 	throw Exception(EXLOC, msg);
@@ -196,30 +168,30 @@ void NetHandler::writeMsg()
     
     memcpy(_msgBuf, (char*)sizeInfo, sizeInfo.length() - 1 );
     
-    int i = sizeInfo.length() - 1;
+    unsigned i = sizeInfo.length() - 1;
     while ( i < _sizeInfoLen)
     {
 	_msgBuf[i] = '@';
 	i++;
     }
     
-    int sendByte = 0;
+    unsigned sendByte = 0;
     while ( sendByte < _msgSize + _sizeInfoLen)
     {
-	int i;	
-	int sendSize;
+	unsigned sendSize;
 
 	if ( _maxSendLen < _msgSize + _sizeInfoLen - sendByte )
 	    sendSize =  _maxSendLen; 
 	else 
 	    sendSize = _msgSize + _sizeInfoLen - sendByte;
 
+	int i;
 	if ( ( i = ::send(_socket, (char*)((long long)_msgBuf + (long)sendByte), sendSize,0) ) == -1 )
 	{
 	    Chain msg = Chain("send system error : ") + Chain(strerror(errno));	 
 	    throw Exception(EXLOC, msg);
 	}	
-	sendByte += i;		
+	sendByte += (unsigned)i;		
     }
 }
 
@@ -238,8 +210,7 @@ bool NetHandler::recvAck()
 void NetHandler::sendAck()
 {
     char ack = 1;
-    int ackSize;
-    
+    int ackSize;    
     if ( ( ackSize = ::send(_socket, &ack,1,0)) == -1)
     {
 	Chain msg = Chain("send system error : ") + Chain(strerror(errno));
@@ -250,8 +221,7 @@ void NetHandler::sendAck()
 void NetHandler::sendNack()
 {
     char ack = 0;
-    int ackSize;
-    
+    int ackSize;    
     if ( ( ackSize = ::send(_socket, &ack,1,0)) == -1)
     {
 	Chain msg = Chain("send system error : ") + Chain(strerror(errno));
@@ -284,20 +254,18 @@ char* NetHandler::getMsg()
     return (char*)( (long long)_msgBuf + _sizeInfoLen);
 }
 
-int NetHandler::getMsgSize()
+unsigned NetHandler::getMsgSize()
 {
     return _msgSize;
 }
 
-void NetHandler::setMsg(char* msg, int size)
+void NetHandler::setMsg(char* msg, unsigned size)
 {
     if ( size > _msgBufSize )
     {
 	delete _msgBuf;
 	_msgBufSize = size;
 	_msgBuf = new char[_msgBufSize + _sizeInfoLen];
-	// Chain msg = Chain("Message too long : ") + Chain(size) + Chain(" bytes");
-	// throw Exception(EXLOC, msg);
     }
     if ( size > 0 )
 	memcpy((char*)((long long)_msgBuf + _sizeInfoLen), msg, size);
@@ -305,7 +273,7 @@ void NetHandler::setMsg(char* msg, int size)
     _msgSize=size;
 }
 
-int NetHandler::concatPos()
+unsigned NetHandler::concatPos()
 {
     return _concatPos;
 }
@@ -317,15 +285,14 @@ void NetHandler::concatReset()
 
 void NetHandler::concatAdd(const Chain& s)
 {
-    concatAdd((char*)s, s.length()-1);
+    concatAdd((char*)s, (unsigned)s.length()-1);
 }
 
-void NetHandler::concatAdd(char* msg, int size)
+void NetHandler::concatAdd(char* msg, unsigned size)
 {
     if ( size + _concatPos > _msgBufSize )
     {
-
-	int newSize = size + _concatPos;
+	unsigned newSize = size + _concatPos;
 	
 	char *newBuf = new char[newSize + _sizeInfoLen];
 
@@ -349,7 +316,7 @@ void NetHandler::disconnect()
 {
     if (_socket )
     {
-	CLOSESOCKET(_socket);
+	::close(_socket);
 	_socket=0;
     }
 }
