@@ -24,15 +24,9 @@
 #include <string.h> 
 
 #ifndef LFCNOCURSES 
-
-#ifdef HAVE_MINGW 
-#include <ncurses/ncurses.h> 
-#else 
 #include <ncurses.h> 
 #endif 
 
-#endif 
-
 #include "Chain.h" 
 #include "ListT.h" 
 #include "Datetime.h" 
