@@ -39,7 +39,7 @@ public:
 
     void prepare();
 
-    int replace(const Chain& src, Chain& target);
+    unsigned long replace(const Chain& src, Chain& target);
     
 private:
     
